increase delay waiting for wheel job to start

fixes #1543
diff --git a/tasks.py b/tasks.py
index c109f14..74ff6b1 100644
--- a/tasks.py
+++ b/tasks.py
@@ -17,9 +17,9 @@
 
 
 def wait_for_build_completed(session):
     # Wait 3 seconds before actually checking if the build is complete, to
     # ensure that it had time to really start.
-    time.sleep(3)
+    time.sleep(20)
     while True:
         response = session.get(
             "{0}/lastBuild/api/json/".format(JENKINS_URL),
@@ -17,9 +17,9 @@
 
 def wait_for_build_completed(session):
-    # Wait 3 seconds before actually checking if the build is complete, to
+    # Wait 20 seconds before actually checking if the build is complete, to
     # ensure that it had time to really start.